# Houston

Visual Studio Code theme featuring cool blues, minty greens, and soft purples and [Astro](https://github.com/withastro/astro)'s mascot Houston.

![Preview of Houston Theme](assets/preview.jpg)

## Issues

Houston is a work in progress. Please [open an issue on our repository](https://github.com/withastro/houston-vscode/issues).
